# -*- mode: rpm-spec; mode: folding -*-
# vim: set ft=spec:
# vim600: set fdm=marker:

#%%define patchlevel rc14

Name: dhcp
Version: 3.0.6
Release: alt1
Serial: 1

Summary: Dynamic Host Configuration Protocol (DHCP) distribution
License: BSD-like
Group: System/Servers
Url: http://www.isc.org/sw/dhcp/
Packager: Dmitry V. Levin <ldv@altlinux.org>

%define srcname %name-%version%{?patchlevel:%patchlevel}
Source0: ftp://ftp.isc.org/isc/%name/%srcname.tar
Source1: dhcp-dynamic-dns-examples.tar
Source2: dhcpd.conf.sample
Source3: update_dhcp.pl
Source4: dhcpd.init
Source5: dhcrelay.init
Source6: dhclient-enter-hooks
Source7: dhclient-exit-hooks
Source8: dhcpd.sysconfig
Source9: dhcrelay.sysconfig
Source10: dhcpd.chroot.all
Source11: dhcpd.chroot.conf
Source12: dhcpd.chroot.lib

Patch0: dhcp-3.0.5-alt-warnings.patch
Patch1: dhcp-3.0.3-alt-defaults.patch
Patch2: dhcp-3.0.3-rh-owl-alt-script.patch
Patch3: dhcp-3.0.3-owl-alt-drop_priv.patch
Patch4: dhcp-3.0.3-alt-daemonize.patch
Patch5: dhcp-3.0.5-owl-alt-support-contact.patch
Patch6: dhcp-3.0.4-owl-bound.patch

Patch11: dhcp-3.0.3-rh-alt-makefile.patch
Patch12: dhcp-3.0.3-rh-dhcpctl-man.patch
Patch13: dhcp-3.0.3-rh-assemble_udp_ip_header.patch
Patch14: dhcp-3.0.3-rh-failover-ports.patch

# due to copy_resolv_conf/copy_resolv_lib
BuildPreReq: chrooted >= 0.3

BuildPreReq: groff-base, libcap-devel

# Chrooted environments
%define ROOT %_localstatedir/%name

%package common
Summary: Dynamic Host Configuration Protocol (DHCP) distribution
Group: System/Servers
PreReq: shadow-utils

%package client
Summary: The ISC DHCP client daemon
Group: System/Servers
PreReq: %name-common = %serial:%version-%release, service

%package server
Summary: The ISC DHCP server daemon
Group: System/Servers
PreReq: %name-common = %serial:%version-%release, service
Requires: /var/empty
Provides: %name = %serial:%version-%release
Obsoletes: dhcp, dhcpd

%package relay
Summary: The ISC DHCP relay daemon
Group: System/Servers
PreReq: %name-common = %serial:%version-%release, service
Requires: /var/empty

%package omshell
Summary: The ISC DHCP OMAPI command shell tool
Group: System/Servers
PreReq: %name-common = %serial:%version-%release

%package devel
Summary: Development headers and static libraries for the dhcpctl API
Group: Development/Other
Requires: dhcp-common = %serial:%version-%release

# {{{ descriptions
%description
The ISC Dynamic Host Configuration Protocol distribution provides a
freely redistributable reference implementation of all aspects of the
DHCP protocol.

%description common
The ISC Dynamic Host Configuration Protocol distribution provides a
freely redistributable reference implementation of all aspects of the
DHCP protocol.

This package contains files and directories common for the ISC DHCP
client, server and relay subpackages.

%description client
The Internet Software Consortium DHCP Client, dhclient, provides a
means for configuring one or more network interfaces using the Dynamic
Host Configuration Protocol, BOOTP protocol, or if these protocols
fail, by statically assigning an address.

%description server
The Internet Software Consortium DHCP Server, dhcpd, implements the
Dynamic Host Configuration Protocol (DHCP) and the Internet Bootstrap
Protocol (BOOTP).  DHCP allows hosts on a TCP/IP network to request
and be assigned IP addresses, and also to discover information about
the network to which they are attached.  BOOTP provides similar
functionality, with certain restrictions.

%description relay
The Internet Software Consortium DHCP Relay Agent, dhcrelay, provides a
means for relaying DHCP and BOOTP requests from a subnet to which no
DHCP server is directly connected to one or more DHCP servers on other
subnets.

You will have to define the environment variable SERVERS and optionally
OPTIONS in /etc/sysconfig/dhcrelay before starting the server.

%description omshell
The OMAPI Command Shell, omshell, provides an interactive way to connect
to, query, and possibly change, the ISC DHCP Server's state via OMAPI,
the Object Management API.  By using OMAPI and omshell, you do not have
to stop, make changes, and then restart the DHCP server, but can make
the changes while the server is running.  Omshell provides a way of
accessing OMAPI.

%description devel
DHCP devel contains header files and static libraries for developing
with the Internet Software Consortium (ISC) dhcpctl API.

# }}}

%prep
%setup -q -n %srcname -a1
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1

%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1

find -type f -name \*.orig -delete -print

install -pm644 %SOURCE3 .
find -type f -print0 |
	xargs -r0 grep -EZl '(/etc|ETCDIR)/(dhclient|dhcpd|dhcrelay)' |
	xargs -r0 %__subst -p 's,\(/etc\|ETCDIR\)/\(dhclient\|dhcpd\|dhcrelay\),\1/%name/\2,g' --

%build
%add_optflags -fpie -fno-strict-aliasing -Wno-unused -Werror -Dlint
./configure --copts "%optflags"
%make_build CC=gcc DEBUG= LIBDIR=%_libdir

# {{{ install

%install
rln()
{
	local target=$1 && shift
	local source=$1 && shift
	target=`relative "$target" "$source"`
	ln -snf "$target" "%buildroot$source"
}

mkdir -p %buildroot{%ROOT,%_sysconfdir/{sysconfig,%name/dhclient.d}}
%make_install install DESTDIR=%buildroot LIBDIR=%_libdir

# dhcpd
install -pD -m600 %SOURCE2 %buildroot%_sysconfdir/%name/dhcpd.conf.sample
install -pD -m755 %SOURCE4 %buildroot%_initdir/dhcpd
install -pD -m644 %SOURCE8 %buildroot%_sysconfdir/sysconfig/dhcpd
mkdir -p %buildroot%ROOT/dhcpd/state
touch %buildroot%ROOT/dhcpd/state/dhcpd.leases
# Make use of syslogd-1.4.1-alt11 /etc/syslog.d/ feature.
mkdir -p %buildroot%ROOT/dhcpd/dev
mksock %buildroot%ROOT/dhcpd/dev/log
mkdir -p %buildroot%_sysconfdir/syslog.d
ln -s %ROOT/dhcpd/dev/log %buildroot%_sysconfdir/syslog.d/dhcpd
# Resolver infrastructure
for n in all conf lib; do
	install -pD -m750 "$RPM_SOURCE_DIR/dhcpd.chroot.$n" \
		"%buildroot%_sysconfdir/chroot.d/dhcpd.$n"
done
%__subst -p 's,%%ROOT,%ROOT/dhcpd,g' "%buildroot%_sysconfdir/chroot.d/"*
mkdir -p %buildroot%ROOT/dhcpd{%_sysconfdir,/%_lib,/var/{nis,yp/binding}}
touch %buildroot%ROOT/dhcpd{%_sysconfdir/{localtime,hosts,services,{host,nsswitch,resolv}.conf},/var/nis/NIS_COLD_START}

# dhcrelay
install -pD -m755 %SOURCE5 %buildroot%_initdir/dhcrelay
install -pD -m644 %SOURCE9 %buildroot%_sysconfdir/sysconfig/dhcrelay

# dhclient
rln /sbin/dhclient-script %_sysconfdir/%name/
install -m755 %SOURCE6 %buildroot%_sysconfdir/%name/
install -m755 %SOURCE7 %buildroot%_sysconfdir/%name/
mkdir -p %buildroot%ROOT/dhclient/state
touch %buildroot%ROOT/dhclient/state/dhclient.leases
echo '# DHCP client config file' > %buildroot%_sysconfdir/%name/dhclient.conf
chmod 644 %buildroot%_sysconfdir/%name/dhclient.conf
mkdir -p %buildroot%_sysconfdir/%name/dhclient.d
echo '#!/bin/sh' > %buildroot%_sysconfdir/%name/dhclient.d/enter001.null-hook
echo '#!/bin/sh' > %buildroot%_sysconfdir/%name/dhclient.d/exit001.null-hook
install -p contrib/sethostname.sh %buildroot%_sysconfdir/%name/dhclient.d/enter010.sethostname
chmod 644 %buildroot%_sysconfdir/%name/dhclient.d/*

# docs
%define docdir %_docdir/%srcname
rm -rf %buildroot%docdir
mkdir -p %buildroot%docdir
cp -a LICENSE README RELNOTES update_dhcp.pl doc \
	%buildroot%docdir/

# }}}

# {{{ scripts

%pre common
/usr/sbin/groupadd -r -f %name

%pre client
%__rm -f /var/run/dhclient.restart
if [ $1 -ge 2 ] && /sbin/start-stop-daemon --stop --test --exec /sbin/dhclient --pidfile /var/run/dhclient.pid --user root >/dev/null 2>&1; then
	touch /var/run/dhclient.restart
fi

# relocate dhcp.d
if [ ! -d %_sysconfdir/%name/dhclient.d -a -d %_sysconfdir/%name/dhcp.d ]; then
	%__mv -v %_sysconfdir/%name/dhcp.d %_sysconfdir/%name/dhclient.d
fi

# relocate dhclient.leases
if [ ! -f %ROOT/dhclient/state/dhclient.leases -a -f %ROOT/dhclient.leases ]; then
	%__mkdir_p %ROOT/dhclient/state
	%__cp -pv %ROOT/dhclient.leases %ROOT/dhclient/state/
fi

%post client
if [ -f /var/run/dhclient.restart ]; then
	%__rm -f /var/run/dhclient.restart
	echo 'Please restart the ISC DHCP client daemon manually.'
fi

%pre server
/usr/sbin/useradd -r -n -g %name -d %ROOT/dhcpd -s /dev/null -c 'The ISC DHCP server daemon' dhcpd >/dev/null 2>&1 ||:
%__rm -f /var/run/dhcpd.restart
# stop _old_ dhcpd if running
if [ $1 -eq 1 ] && [ -x %_initdir/dhcpd ] && %_initdir/dhcpd status >/dev/null 2>&1; then
	%_initdir/dhcpd condstop && touch /var/run/dhcpd.restart ||:
fi

# relocate dhcpd.conf
if [ ! -f %_sysconfdir/%name/dhcpd.conf -a -f %_sysconfdir/dhcpd.conf ]; then
	%__mkdir_p %_sysconfdir/%name
	%__mv -v %_sysconfdir/dhcpd.conf %_sysconfdir/%name/
fi

# relocate dhcpd.leases
if [ ! -f %ROOT/dhcpd/state/dhcpd.leases -a -f %ROOT/dhcpd.leases ]; then
	%__mkdir_p %ROOT/dhcpd/state
	%__mv -v %ROOT/dhcpd.leases %ROOT/dhcpd/state/
fi

if [ $1 = 0 ]; then
	%__rm -f %ROOT/dhcpd/%_lib/* %ROOT/dhcpd/var/yp/binding/*
fi

%post server
%_sysconfdir/chroot.d/dhcpd.all
%post_service dhcpd
if [ -f /var/run/dhcpd.restart ]; then
	%__rm -f /var/run/dhcpd.restart
	%_initdir/dhcpd start ||:
fi

%preun server
%preun_service dhcpd

%triggerpostun -- %name
[ $1 = 0 ] || exit 0
/sbin/chkconfig --add dhcpd

%pre relay
/usr/sbin/useradd -r -n -g %name -d /var/empty -s /dev/null -c 'The ISC DHCP relay daemon' dhcrelay >/dev/null 2>&1 ||:
%__rm -f /var/run/dhcrelay.restart
if [ $1 -ge 2 ] && [ -x %_initdir/dhcrelay ] && %_initdir/dhcrelay status >/dev/null 2>&1; then
	%_initdir/dhcrelay condstop && touch /var/run/dhcrelay.restart ||:
fi

%post relay
if [ -f /var/run/dhcrelay.restart ]; then
	%__rm -f /var/run/dhcrelay.restart
	%_initdir/dhcrelay start ||:
else
	%post_service dhcrelay
fi

%preun relay
%preun_service dhcrelay

# }}}

# {{{ files

%files common
%dir %ROOT
%dir %_sysconfdir/%name
%dir %docdir
%docdir/[A-Z]*
%docdir/doc

%files client
%config %_sysconfdir/%name/dhclient-*-hooks
%config(noreplace) %_sysconfdir/%name/dhclient.d
%config(noreplace) %_sysconfdir/%name/dhclient.conf
%_sysconfdir/%name/dhclient-script
/sbin/dhclient*
%_man5dir/dhclient.*
%_man8dir/dhclient*
%attr(700,root,dhcp) %dir %ROOT/dhclient
%attr(700,root,dhcp) %dir %ROOT/dhclient/state
%attr(644,root,dhcp) %config(noreplace) %verify(not md5 mtime size) %ROOT/dhclient/state/dhclient.leases

%files server
%_sysconfdir/syslog.d/*
%config %_sysconfdir/chroot.d/dhcpd.*
%config %_initdir/dhcpd
%config(noreplace) %_sysconfdir/sysconfig/dhcpd
%_sbindir/dhcpd
%_man5dir/dhcpd.*
%_man5dir/dhcp-options.*
%_man5dir/dhcp-eval.*
%_man8dir/dhcpd.*
%attr(0750,root,dhcp) %dir %ROOT/dhcpd
%attr(1770,root,dhcp) %dir %ROOT/dhcpd/state
%attr(0644,dhcpd,dhcp) %config(noreplace) %verify(not md5 mtime size) %ROOT/dhcpd/state/dhcpd.leases
%dir %attr(0710,root,dhcp) %ROOT/dhcpd/dev
%ghost %attr(666,root,root) %ROOT/dhcpd/dev/*
# Resolver infrastructure
%dir %ROOT/dhcpd/%_lib
%dir %ROOT/dhcpd%_sysconfdir
%ghost %verify(not md5 mtime size) %ROOT/dhcpd%_sysconfdir/*
%dir %ROOT/dhcpd/var
%dir %ROOT/dhcpd/var/nis
%ghost %config(missingok) %verify(not md5 mtime size) %ROOT/dhcpd/var/nis/NIS_COLD_START
%dir %ROOT/dhcpd/var/yp
%dir %ROOT/dhcpd/var/yp/binding
%dir %_sysconfdir/%name
%doc %_sysconfdir/%name/dhcpd.conf.sample
%dir %docdir
%docdir/update_dhcp.pl

%files relay
%config %_initdir/dhcrelay
%config(noreplace) %_sysconfdir/sysconfig/dhcrelay
%_sbindir/dhcrelay
%_man8dir/dhcrelay.*

%files omshell
%_bindir/omshell
%_man1dir/omshell.*
  
%files devel
%_includedir/*
%_libdir/*
%_man3dir/*

# }}}

%changelog
* Mon Jul 09 2007 Dmitry V. Levin <ldv@altlinux.org> 1:3.0.6-alt1
- Updated to 3.0.6 release.

* Mon Nov 06 2006 Dmitry V. Levin <ldv@altlinux.org> 1:3.0.5-alt1
- Updated to 3.0.5 release.
- Imported a bounds checking patch from Owl.

* Fri Oct 13 2006 Dmitry V. Levin <ldv@altlinux.org> 1:3.0.5-alt0.3
- Updated to 3.0.5 rc3.
- Fixed build with -D_FORTIFY_SOURCE=2 -Werror.

* Tue Sep 05 2006 Dmitry V. Levin <ldv@altlinux.org> 1:3.0.5-alt0.2
- Updated to 3.0.5 rc2.

* Thu Jun 08 2006 Dmitry V. Levin <ldv@altlinux.org> 1:3.0.4-alt1
- Updated to 3.0.4 release.
- Packaged libdst.a (#8990).

* Wed Oct 26 2005 Dmitry V. Levin <ldv@altlinux.org> 1:3.0.3-alt1
- Updated to 3.0.3 release.
- Updated patches.
- Imported few patches from RH's dhcp-3.0.3-10 package.
- dhcpd, dhcrelay: Fixed daemonize code.
- dhcpd: Enhanced droppriv patch to handle failover protocol
  (fixes #8346).

* Mon Apr 18 2005 Dmitry V. Levin <ldv@altlinux.org> 1:3.0.2-alt1
- Updated to 3.0.2 release.
- Updated patches.
- Fixed license tag (distributable -> BSD-like).
- Provided the proper support contact information.
- dhcp-server:
  + disabled %%verify check for files which are
    ususally changed after package installation.
  + relocated dhcpd.conf.sample to %_sysconfdir/%name/,
    changed startup script to point at this sample
    when needed (#5676).

* Thu Oct 28 2004 Dmitry V. Levin <ldv@altlinux.org> 1:3.0.1-alt12
- dhcp-server: Package %_sysconfdir/syslog.d/%name symlink.

* Thu Aug 12 2004 Dmitry V. Levin <ldv@altlinux.org> 1:3.0.1-alt11
- dhcp-server: Complemented resolver infrastructure added
  in previous release.

* Wed Aug 11 2004 Dmitry V. Levin <ldv@altlinux.org> 1:3.0.1-alt10
- Updated to 3.0.1 release.
- Added resolver infrastructure to the dhcpd chroot jail.

* Mon Jul  5 2004 Sergey Bolshakov <sbolshakov@altlinux.ru> 1:3.0.1-alt9
- fixed #4665

* Sun Jun 27 2004 Sergey Bolshakov <sbolshakov@altlinux.ru> 1:3.0.1-alt8
- 3.0.1rc14
- applying changes from Dmitry V. Levin <ldv@altlinux.org> :
  + Renamed dhcp subpackage to dhcp-server subpackage.
  + Merged -devel-static subpackage into -devel subpackage.
  + Merged Owl patches:
    rh-owl-alt-script, owl-man, owl-alt-warnings, owl-alt-drop_priv.
  + Implemented chroot jailing for dhcpd and dhcrelay by default;
    changed location of leases files.
  + Rewritten startup scripts to new rc scheme;
    removed extra ifconfig logic for a while.
  + Updated summaries and descriptions.
  + Corrected interpackage dependencies.
  + Moved update_dhcp.pl script to %%doc.
  + Relocated documentation to %_docdir/%srcname.
  + Changed default dhcpd config location to %_sysconfdir/%name/dhcpd.conf.
  + Changed %_sysconfdir/%name/dhcp.d to %_sysconfdir/%name/dhclient.d.
  + Specfile cleanup.

* Wed Jun 23 2004 Grigory Milev <week@altlinux.ru> 1:3.0.1-alt7.rc14
- new version released

* Thu Feb 26 2004 Grigory Milev <week@altlinux.ru> 1:3.0.1-alt6.rc13
- new version released
- fix start/stop dhcprelay script
- fix start/stop dhcp script

* Mon Apr 21 2003 Grigory Milev <week@altlinux.ru> 1:3.0.1-alt5
- new version released (3.0.1rc11)
- added config dir /etc/dhcp && hooks dir /etc/dhcp/dhcp.d
- added dhclient-enter-hooks && dhclient-exit-hooks

* Mon Dec  9 2002 Grigory Milev <week@altlinux.ru> 1:3.0.1-alt4
- new rc version released
- security patch added: Potential Vulnerabilities in ISC DHCPD [VU#284857]

* Wed Oct 30 2002 Stanislav Ievlev <inger@altlinux.ru> 1:3.0.1-alt3
- real changelog fix. Grigory, please use normal add_changelog util

* Fri Oct 25 2002 Grigory Milev <week@altlinux.ru> 3.0.1-alt2
- rebuild with gcc3.2
- mv dhclient-script to /sbin
  make link /sbin/dhclient-script -> /etc/dhclient-script for compatible

* Wed Oct 23 2002 Grigory Milev <week@altlinux.ru> 3.0.1-alt1
- rebuild with gcc3

* Wed May 15 2002 Grigory Milev <week@altlinux.ru> 3.0.1-alt0.8
- new rc version released with security patches

* Tue Mar 26 2002 Grigory Milev <week@altlinux.ru> 3.0.1-alt0.7
- make dhcpd.leases as noreplace config file

* Thu Mar 21 2002 Grigory Milev <week@altlinux.ru> 3.0.1-alt0.6
- Fixed init script to work with chkconfig

* Thu Feb 21 2002 Grigory Milev <week@altlinux.ru> 3.0.1-alt0.5
- rewriten init script, for correct work with ethernet
  aliases (ex: eth0:1) and subnet test for available
  in dhcpd.conf (thanks to Vadim Illarionov <DIMMeach@NewMail.ru>)

* Wed Feb 20 2002 Grigory Milev <week@altlinux.ru> 3.0.1-alt0.4
- fixed init script
- remake post and preun scripts

* Fri Feb 15 2002 Grigory Milev <week@altlinux.ru> 3.0.1-alt0.3
- fixed post uninstall script

* Tue Feb 12 2002 Grigory Milev <week@altlinux.ru> 3.0.1-alt0.2
- correct init script for find interfaces from ifcfg scripts
- if you need dhcp on some interface, add DHCP=yes to ifcfg script
- minor spec cleanup

* Mon Nov 05 2001 Konstantin Volckov <goldhead@altlinux.ru> 3.0.1-alt0.1
- 3.0.1rc3
- Added devel, devel-static, omshell, relay & common packages

* Wed Jan 17 2001 Dmitry V. Levin <ldv@fandra.org> 2.0pl5-ipl2mdk
- RE adaptions.

* Fri Nov 17 2000 Florin Grad <florin@mandrakesoft.com> 2.0pl5-2mdk
- chkconfig is now set to 3,4,5

* Mon Nov 06 2000 Florin Grad <florin@mandrakesoft.com> 2.0pl5-1mdk
- Mandrake adaptations. this is the actual stable version

* Sun Sep 10 2000 Florian La Roche <Florian.LaRoche@redhat.de>
- update to 2.0pl5
- redo buildroot patch

* Wed Aug 30 2000 Matt Wilson <msw@redhat.com>
- rebuild to cope with glibc locale binary incompatibility, again

* Mon Aug 14 2000 Preston Brown <pbrown@redhat.com>
- check for existence of /var/lib/dhcpd.leases in initscript before starting

* Wed Jul 19 2000 Jakub Jelinek <jakub@redhat.com>
- rebuild to cope with glibc locale binary incompatibility

* Sat Jul 15 2000 Bill Nottingham <notting@redhat.com>
- move initscript back

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Fri Jul  7 2000 Florian La Roche <Florian.LaRoche@redhat.com>
- /etc/rc.d/init.d -> /etc/init.d
- fix /var/state/dhcp -> /var/lib/dhcp

* Fri Jun 16 2000 Preston Brown <pbrown@redhat.com>
- condrestart for initscript, graceful upgrades.

* Thu Feb 03 2000 Erik Troan <ewt@redhat.com>
- gzipped man pages
- marked /etc/rc.d/init.d/dhcp as a config file

* Mon Jan 24 2000 Jakub Jelinek <jakub@redhat.com>
- fix booting of JavaStations
  (reported by Pete Zaitcev <zaitcev@metabyte.com>).
- fix SIGBUS crashes on SPARC (apparently gcc is too clever).

* Fri Sep 10 1999 Bill Nottingham <notting@redhat.com>
- chkconfig --del in %preun, not %postun

* Mon Aug 16 1999 Bill Nottingham <notting@redhat.com>
- initscript munging

* Fri Jun 25 1999 Jeff Johnson <jbj@redhat.com>
- update to 2.0.

* Fri Jun 18 1999 Bill Nottingham <notting@redhat.com>
- don't run by default

* Wed Jun  2 1999 Jeff Johnson <jbj@redhat.com>
- update to 2.0b1pl28.

* Tue Apr 06 1999 Preston Brown <pbrown@redhat.com>
- strip binaries

* Mon Apr 05 1999 Cristian Gafton <gafton@redhat.com>
- copy the source file in %prep, not move

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com>
- auto rebuild in the new build environment (release 4)

* Mon Jan 11 1999 Erik Troan <ewt@redhat.com>
- added a sample dhcpd.conf file
- we don't need to dump rfc's in /usr/doc

* Sun Sep 13 1998 Cristian Gafton <gafton@redhat.com>
- modify dhcpd.init to exit if /etc/dhcpd.conf is not present

* Sat Jun 27 1998 Jeff Johnson <jbj@redhat.com>
- Upgraded to 2.0b1pl6 (patch1 no longer needed).

* Thu Jun 11 1998 Erik Troan <ewt@redhat.com>
- applied patch from Chris Evans which makes the server a bit more paranoid
  about dhcp requests coming in from the wire

* Mon Jun 01 1998 Erik Troan <ewt@redhat.com>
- updated to dhcp 2.0b1pl1
- got proper man pages in the package

* Tue Mar 31 1998 Erik Troan <ewt@redhat.com>
- updated to build in a buildroot properly
- don't package up the client, as it doens't work very well <sigh>

* Tue Mar 17 1998 Bryan C. Andregg <bandregg@redhat.com>
- Build rooted and corrected file listing.

* Mon Mar 16 1998 Mike Wangsmo <wanger@redhat.com>
- removed the actual inet.d links (chkconfig takes care of this for us)
  and made the %postun section handle upgrades.

* Mon Mar 16 1998 Bryan C. Andregg <bandregg@redhat.com>
- First package.

